camelot.camelot.view.controls.modeltree.ModelTree

Package camelot :: Package camelot :: Package view :: Package controls :: Module modeltree :: Class ModelTree |
[hide private]
[frames] | no frames]

# Class ModelTree

source code

Custom tree widget

Instance Methods | [hide private]
__init__(self, header_labels=[''], parent=None) | source code
fix_header_labels(self) | source code
clear_model_items(self) | source code
mousePressEvent(self, event) Custom context menu | source code
leaveEvent(self, event) | source code
mouseMoveEvent(self, event) | source code
focusInEvent(self, event) | source code